
=======================
PyAMS_utils i18n module
=======================

This module can be used to define server locales:

    >>> from pyramid.testing import setUp, tearDown
    >>> config = setUp(hook_zca=True)

    >>> config.add_settings({'pyams.locale.lc_all': 'C.UTF-8'})

    >>> from pyams_utils.i18n import set_locales
    >>> set_locales(config.registry.settings)

    >>> import locale
    >>> locale.getlocale(locale.LC_ALL)
    ('en_US', 'UTF-8')


Tests cleanup:

    >>> tearDown()
